#!/usr/bin/env python

import argparse,os,sys,subprocess,time,datetime
import pebble as libpebble
from random import randint

def cmd_remote(pebble):

    def music_control_handler(endpoint, resp):
        print "Got " + str(resp)
        if resp == "PLAYPAUSE":
            print 'PLAYPAUSE!'
        elif resp == "PREVIOUS":
            print 'PLAYPAUSE!'
        elif resp == "NEXT":
            print 'NEXT!'
        update_metadata()

    def update_metadata():
        artist = "Ekeberg"
        album = "Basket 4"
        title = str(randint(1,10))
        try:
            pebble.set_nowplaying_metadata(title, album, artist)
        except Exception as e:
            print 'error!' + str(e)

    pebble.register_endpoint("MUSIC_CONTROL", music_control_handler)

    print 'waiting for control events'
    try:
        while True:
            update_metadata()
            if pebble._ser.is_alive():
                print 'alive @'+str(datetime.datetime.now())+'...'
                time.sleep(5)
            else:
                break
    except KeyboardInterrupt:
        pass
    except Exception as e:
        print 'butterror!' + str(e)
    return

def cmd_notification_email(pebble):
    print "Sending email notification"
    pebble.notification_email("en", "to", "tre")

def main():
    parser = argparse.ArgumentParser(description='a utility belt for pebble development')
    parser.add_argument('--pebble_id', type=str, help='the last 4 digits of the target Pebble\'s MAC address. \nNOTE: if \
                        --lightblue is set, providing a full MAC address (ex: "A0:1B:C0:D3:DC:93") won\'t require the pebble \
                        to be discoverable and will be faster')

    parser.add_argument('--lightblue', action="store_true", help='use LightBlue bluetooth API')
    parser.add_argument('--pair', action="store_true", help='pair to the pebble from LightBlue bluetooth API before connecting.')
    args = parser.parse_args()

    attempts = 0
    while True:
#        if attempts > MAX_ATTEMPTS:
#            raise 'Could not connect to Pebble'
        try:
            pebble_id = args.pebble_id
            if pebble_id is None and "PEBBLE_ID" in os.environ:
                pebble_id = os.environ["PEBBLE_ID"]
            pebble = libpebble.Pebble(pebble_id, args.lightblue, args.pair)

            try:
                print "Got Pebble"
                # cmd_notification_email(pebble)
                # pebble.disconnect()
                # time.sleep(2)
                # exit()
                cmd_remote(pebble)
            except Exception as e:
                print 'error', e
                pebble.disconnect()
                raise e
                return

            attempts = 0
            pebble.disconnect()
            time.sleep(2)
        except:
            print 'error (2)'
            time.sleep(2)
            attempts += 1

if __name__ == '__main__':
    main()

